Learn R Programming

covid19italy (version 0.3.1)

italy_region: The 2019 Novel Coronavirus COVID-19 (2019-nCoV) Italy Regions Outbreak Dataset

Description

daily summary of the Coronavirus (COVID-19) pandemic cases in Italy's regions

Usage

italy_region

Arguments

Format

A data.frame object

Details

The dataset contains the daily summary of the Coronavirus pandemic cases in Italy's regions. The data includes the following fields:

- date - date of notification (Date class)

- region_code - region code

- region_name - region names

- lat - latitude point

- long - Longitude point

- hospitalized_with_symptoms - number of hospitalised patients with symptoms

- intensive_care - intensive Care

- total_hospitalized - total hospitalised patients

- home_confinement - home confinement

- cumulative_positive_cases - total amount of current positive cases (Hospitalised patients + Home confinement)

- daily_positive_cases - news amount of current positive cases (Hospitalised patients + Home confinement)

- recovered - recovered cases

- death - death cases

- positive_clinical_activity - positive cases emerged from clinical activity

- positive_surveys_tests - positive cases emerging from surveys and tests, planned at national or regional level

- cumulative_cases - total positive, recovered, and death cases

- total_tests - number of tests performed

- total_people_tested - total number of people tested

- new_intensive_care - daily admissions to intensive care

- total_positive_tests - total positive tests

- total_fast_tests - total fast tests

- daily_positive_tests - daily positive tests

- daily_fast_tests - daily fasts tests

- nuts_code_1 - NUTS statistical regions of Italy more details available more details available here

- nuts_code_2 - NUTS statistical regions of Italy more details available here

- region_spatial - the spatial region names as in the output of the `ne_states` function from the **rnaturalearth** package

Examples

Run this code
# NOT RUN {
data(italy_region)

head(italy_region)

# }

Run the code above in your browser using DataLab